date

# XMLRésuméLibrary: User Guide

county | Element Reference | dayOfMonth

## Name

date — A specific instant in time

## Synopsis

### Content Model

    (((dayOfMonth)?,month)?,year)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `date` element represents a specific instant in time, with at least year-level granularity, and at most day-level granularity.

When contained inside a `pub` element, `date` represents the date that the work was published.

When contained inside a `clearance` element, `date` represents the date that the security clearance was granted.

### Note

The `month` element was made optional in version 1.4.0 of the XML Résumé Library. It was previously required.

To represent a period of time, instead of a specific instant, use `period`.

### Parents

`date` may be contained in these elements: `award`, `birth`, `clearance`, `degree`, `from`, `job`, `lastModified`, `membership`, `pub`, `to`

## See Also

`period`.

## Examples

    <date>
      <dayOfMonth>27</dayOfMonth>
      <month>November</month>
      <year>1634</year>
    </date>

    <date>
      <month>July</month>
      <year>1457</year>
    </date>

county | Element Reference | dayOfMonth